#!/bin/bash
#######################################
# (c) Copyright 2016 Hewlett Packard Enterprise Development LP.
# Version A.12.00.50
#######################################

########################## 
# Source utility functions. 
########################### 
PATH=$SGSBIN:/bin:/sbin:/usr/bin:/usr/sbin:/usr/lbin:$PATH
export PATH=$PATH

. /etc/cmcluster.conf 

if [[ -z $SG_UTILS ]]; then 
	SG_UTILS=$SGCONF/scripts/mscripts/utils.sh 
fi 
if [[ -f ${SG_UTILS} ]]; then 
	. ${SG_UTILS} 
	if (( $? != 0 )) 
		then 
			echo "ERROR: Unable to source package utility functions file: ${SG_UTILS}" 
			exit 1 
	fi 
else 
	echo "ERROR: Unable to find package utility functions file: ${SG_UTILS}" 
	exit 1 
fi 

KVMMNP_UTILS=$SGROOT/kvmtoolkit/hakvmmnputils.sh 
if [[ -f ${KVMMNP_UTILS} ]]; then 
	. ${KVMMNP_UTILS} 
	if (( $? != 0 )) 
		then 
			echo "ERROR: Unable to source package utility functions file: ${KVMMNP_UTILS}" 
			exit 1 
	fi 
else 
	echo "ERROR: Unable to find package utility functions file: ${KVMMNP_UTILS}" 
	exit 1 
fi

################################################################### 
# 
# Get the environment for this package through utility function 
# sg_source_pkg_env(). 
# 
################################################################### 
sg_source_pkg_env $* 

############################################################# 
# 
#       START FUNCTION 
# 
############################################################ 
function start_function
{    
    typeset -i use_systemd=0
    typeset -i ret=0

    check_libvirt
    if [[ $? -ne 0 ]]; then
        sg_log 0 "libvirtd is not already started"
        sg_log 0 "Attempting to start libvirtd"
        # Attempt restart of libvirtd
        start_libvirt
        if [[ $? -ne 0 ]]; then
            sg_log 0 "ERROR: Failed to start libvirtd"
            sg_log 0 "Try to restart the package after starting libvirtd using service or systemctl command"
            exit_code=1
            return 1
        fi        
        sg_log 0 "Successfully started libvirtd"
    fi
        
    return 0
}

############################################################# 
# 
#       STOP FUNCTION 
# 
############################################################ 
function stop_function 
{
    # Do nothing
    return 0;
} 

################################################################## 
# 
#       VALIDATE FUNCTION 
# 
################################################################# 
function validate_function 
{ 
    # Do nothing
    return 0;
} 

##################################################################
#
#       reconfigure_stop FUNCTION
#
#################################################################
function reconfigure_stop_function
{
    # Do nothing
    return 0;
}

##################################################################
#
#       reconfigure_start FUNCTION
#
#################################################################
function reconfigure_start_function
{
    # Do nothing
    return 0;
}


#mainstart
################################## 
# 
#Start of Routines 
# 
################################# 

# Global Variables
typeset -i exit_code=0
case $1 in
    validate)
        validate_function
        ;;
    start)
        start_function
        ;;
    stop)
        stop_function
        ;;
    reconfigure_stop)
        reconfigure_stop_function
        ;;
    reconfigure_start)
        reconfigure_start_function
        ;;
    *)
        sg_log 0 "Usage: ${0} [ start | stop | validate | reconfigure_start | reconfigure_stop ]"
        ;;
esac
exit $exit_code
#mainend
